summaryrefslogtreecommitdiff
path: root/nuttx/configs/avr32dev1/src
diff options
context:
space:
mode:
authorGregory Nutt <gnutt@nuttx.org>2014-01-24 13:59:24 -0600
committerGregory Nutt <gnutt@nuttx.org>2014-01-24 13:59:24 -0600
commit2b4abec1eabbc0a2b8ea96c799ebd18da253c6c0 (patch)
tree3efd8e41f20b33606e46b8820a89510e6209d27c /nuttx/configs/avr32dev1/src
parentea439de0bb25f37ffc4004b6532bf53810511c3d (diff)
downloadnuttx-2b4abec1eabbc0a2b8ea96c799ebd18da253c6c0.tar.gz
nuttx-2b4abec1eabbc0a2b8ea96c799ebd18da253c6c0.tar.bz2
nuttx-2b4abec1eabbc0a2b8ea96c799ebd18da253c6c0.zip
Rename up_buttons() to board_buttons()
Diffstat (limited to 'nuttx/configs/avr32dev1/src')
-rw-r--r--nuttx/configs/avr32dev1/src/up_buttons.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/nuttx/configs/avr32dev1/src/up_buttons.c b/nuttx/configs/avr32dev1/src/up_buttons.c
index 40c09b4f3..930ed76ea 100644
--- a/nuttx/configs/avr32dev1/src/up_buttons.c
+++ b/nuttx/configs/avr32dev1/src/up_buttons.c
@@ -110,7 +110,7 @@ static xcpt_t up_irqbuttonx(int irq, xcpt_t irqhandler)
*
* Description:
* board_button_initialize() must be called to initialize button resources.
* After that, up_buttons() may be called to collect the current state of
* all buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
@@ -123,18 +123,18 @@ void board_button_initialize(void)
}
/****************************************************************************
- * Name: up_buttons
+ * Name: board_buttons
*
* Description:
* After board_button_initialize() has been called, up_buttons() may be
* called to collect the state of all buttons. up_buttons() returns an
* 8-bit bit set with each bit associated with a button. See the BUTTON*
* definitions in the board.h header file for the meaning of each bit in
* the returned value.
*
****************************************************************************/
-uint8_t up_buttons(void)
+uint8_t board_buttons(void)
{
uint8_t retval;
@@ -110,7 +110,7 @@ static xcpt_t up_irqbuttonx(int irq, xcpt_t irqhandler)
* Description:
* board_button_initialize() must be called to initialize button resources.
- * After that, up_buttons() may be called to collect the current state of
+ * After that, board_buttons() may be called to collect the current state of
* all buttons or up_irqbutton() may be called to register button interrupt
* handlers.
@@ -123,18 +123,18 @@ void board_button_initialize(void)
*
* Description:
- * After board_button_initialize() has been called, up_buttons() may be
- * called to collect the state of all buttons. up_buttons() returns an
+ * After board_button_initialize() has been called, board_buttons() may be
+ * called to collect the state of all buttons. board_buttons() returns an
* 8-bit bit set with each bit associated with a button. See the BUTTON*
* definitions in the board.h header file for the meaning of each bit in